﻿using System;
using Android.App;
using Android.Content;
using Android.Runtime;
using Android.Views;
using Android.Widget;
using Android.OS;
using Com.Syncfusion.Charts;
using Android.Graphics;
using Android.Util;
using Com.Syncfusion.Charts.Enums;
using Com.Syncfusion.Rangenavigator;
using Java.Util;

namespace ChartSample
{
    [Activity(Label = "ChartSample", MainLauncher = true, Icon = "@drawable/icon")]
    public class MainActivity : Activity
    {
        SfChart chart;
        SfChart contentChart;

        SfDateTimeRangeNavigator rangeNavigator;

        Calendar minimum, maximum;
        protected override void OnCreate(Bundle bundle)
        {
            base.OnCreate(bundle);
            
            SetContentView(Resource.Layout.Main);

            LinearLayout layout = new LinearLayout(this);
            layout.Orientation = Android.Widget.Orientation.Vertical;
            
            chart = new SfChart(this);
            chart.LayoutParameters = new ViewGroup.LayoutParams(520, 450);
            chart.SetBackgroundColor(Color.White);

            ObservableArrayList data = new ObservableArrayList();
            data.Add(new ChartDataPoint(new GregorianCalendar(2016, 8, 15, 1, 0).Time, 34));
            data.Add(new ChartDataPoint(new GregorianCalendar(2016, 8, 15, 4, 0).Time, 34));
            data.Add(new ChartDataPoint(new GregorianCalendar(2016, 8, 15, 11, 0).Time, 54));
            data.Add(new ChartDataPoint(new GregorianCalendar(2016, 8, 15, 18, 0).Time, 47));
            data.Add(new ChartDataPoint(new GregorianCalendar(2016, 8, 15, 23, 0).Time, 32));
            data.Add(new ChartDataPoint(new GregorianCalendar(2016, 8, 16, 6, 0).Time, 30));
            data.Add(new ChartDataPoint(new GregorianCalendar(2016, 8, 16, 13, 0).Time, 53));
            data.Add(new ChartDataPoint(new GregorianCalendar(2016, 8, 16, 22, 0).Time, 56));
            data.Add(new ChartDataPoint(new GregorianCalendar(2016, 8, 17, 3, 0).Time, 32));
            data.Add(new ChartDataPoint(new GregorianCalendar(2016, 8, 17, 9, 0).Time, 30));
            data.Add(new ChartDataPoint(new GregorianCalendar(2016, 8, 17, 18, 0).Time, 53));
            data.Add(new ChartDataPoint(new GregorianCalendar(2016, 8, 17, 23, 0).Time, 56));
            data.Add(new ChartDataPoint(new GregorianCalendar(2016, 8, 18, 0, 0).Time, 36));
            data.Add(new ChartDataPoint(new GregorianCalendar(2016, 8, 18, 6, 0).Time, 30));
            data.Add(new ChartDataPoint(new GregorianCalendar(2016, 8, 18, 13, 0).Time, 53));
            data.Add(new ChartDataPoint(new GregorianCalendar(2016, 8, 18, 22, 0).Time, 56));
            data.Add(new ChartDataPoint(new GregorianCalendar(2016, 8, 19, 3, 0).Time, 32));
            data.Add(new ChartDataPoint(new GregorianCalendar(2016, 8, 19, 9, 0).Time, 30));
            data.Add(new ChartDataPoint(new GregorianCalendar(2016, 8, 19, 18, 0).Time, 53));
            data.Add(new ChartDataPoint(new GregorianCalendar(2016, 8, 19, 23, 0).Time, 56));
            data.Add(new ChartDataPoint(new GregorianCalendar(2016, 8, 20, 0, 0).Time, 26));

            DateTimeAxis primary = new DateTimeAxis() {};
            NumericalAxis secondary = new NumericalAxis() { };

            chart.PrimaryAxis = primary;
            chart.SecondaryAxis = secondary;
            
            SplineAreaSeries series = new SplineAreaSeries();
            series.TooltipEnabled = true;
            series.DataMarker.ShowMarker = true;
            series.DataSource = data;
            chart.Series.Add(series);
            
            rangeNavigator = new SfDateTimeRangeNavigator(this);
            rangeNavigator.LayoutParameters = new ViewGroup.LayoutParams(430, 320);

            minimum = new GregorianCalendar(2016, 8, 17, 0, 0);
            maximum = new GregorianCalendar(2016, 8, 18, 0, 0);

            rangeNavigator.Minimum = minimum.Time;
            rangeNavigator.Maximum = maximum.Time;


            contentChart= new SfChart(this)
            {
                PrimaryAxis = new DateTimeAxis() { ShowMajorGridLines = false, Visibility = Visibility.Gone},
                SecondaryAxis = new NumericalAxis() { ShowMajorGridLines = false, Visibility = Visibility.Gone },               
            };
            contentChart.SetBackgroundColor(Color.White);
            contentChart.Series.Add(new SplineAreaSeries() { DataSource = data });
            rangeNavigator.Content = contentChart;

            rangeNavigator.RangeChanged += RangeNavigator_RangeChanged;

            Button previousButton = new Button(this);
            previousButton.Text = "<";
            previousButton.LayoutParameters = new ViewGroup.LayoutParams(50, 100);
            previousButton.SetY(110);
            previousButton.Click += PreviousButton_Click;

            Button nextButton = new Button(this);
            nextButton.Text = ">";
            nextButton.LayoutParameters = new ViewGroup.LayoutParams(50, 100);
            nextButton.SetY(110);
            nextButton.Click += NextButton_Click;

            LinearLayout buttonLayout = new LinearLayout(this);
            buttonLayout.Orientation = Android.Widget.Orientation.Horizontal;
            buttonLayout.SetBackgroundColor(Color.White);

            buttonLayout.AddView(previousButton);
            buttonLayout.AddView(rangeNavigator);
            buttonLayout.AddView(nextButton);
            
            layout.AddView(chart);
            layout.AddView(buttonLayout);
            SetContentView(layout);
        }

        private void NextButton_Click(object sender, EventArgs e)
        {
            if (maximum.Before(new GregorianCalendar(2016, 8, 20, 0, 0, 0)))
            {
                minimum.Add(CalendarField.Date, 1);
                maximum.Add(CalendarField.Date, 1);

                rangeNavigator.Minimum = minimum.Time;
                rangeNavigator.Maximum = maximum.Time;

                rangeNavigator.ViewRangeStart = minimum.Time;
                rangeNavigator.ViewRangeEnd = maximum.Time;


                (contentChart.PrimaryAxis as DateTimeAxis).Minimum = minimum.Time;
                (contentChart.PrimaryAxis as DateTimeAxis).Maximum = maximum.Time;
            }
        }

        private void PreviousButton_Click(object sender, EventArgs e)
        {
            if (minimum.After(new GregorianCalendar(2016, 8, 15, 0, 0, 0)))
            {
                minimum.Add(CalendarField.Date, -1);
                maximum.Add(CalendarField.Date, -1);

                rangeNavigator.Minimum = minimum.Time;
                rangeNavigator.Maximum = maximum.Time;

                rangeNavigator.ViewRangeStart = minimum.Time;
                rangeNavigator.ViewRangeEnd = maximum.Time;


                (contentChart.PrimaryAxis as DateTimeAxis).Minimum = minimum.Time;
                (contentChart.PrimaryAxis as DateTimeAxis).Maximum = maximum.Time;
            }
        }

        private void RangeNavigator_RangeChanged(object sender, SfDateTimeRangeNavigator.RangeChangedEventArgs e)
        {
            (chart.PrimaryAxis as DateTimeAxis).Minimum = e.P0;
            (chart.PrimaryAxis as DateTimeAxis).Maximum = e.P1;

        }
    }
}

